@@ -69,8 +69,8 @@ class RV(ABC):
     def get_extra_attribute(self, k):
         return self._extra_attributes[k]
 
-    def set_tmpl(self, tmpl, is_ostrich=False):
-        self.tmpl = tmpl  # type: ignore
+    def set_tmpl(self, tmpl=None, is_ostrich=False):
+        self.tmpl = tmpl or self.tmpl  # type: ignore
         self.is_ostrich_tmpl = is_ostrich
 
     @property
@@ -212,6 +212,7 @@ class RVI(RV):
     # come after `:SoilModel`
     _post_tmpl = """
     :EvaluationMetrics     {evaluation_metrics}
+    {evaluation_periods}
     :WriteNetcdfFormat     yes
     #:WriteForcingFunctions
     :SilentMode
@@ -307,6 +308,7 @@ class RVI(RV):
             RVI.EvaluationMetrics.NASH_SUTCLIFFE,
             RVI.EvaluationMetrics.RMSE,
         ]
+        self._evaluation_periods = []
         self._suppress_output = False
 
     def configure_from_nc_data(self, fns):
@@ -378,7 +380,8 @@ class RVI(RV):
 
     @evaluation_metrics.setter
     def evaluation_metrics(self, values):
-        if not isinstance(values, (list, set, tuple)):
+
+        if not is_sequence(values):
             values = [values]
         ms = []
         for v in values:
@@ -386,6 +389,17 @@ class RVI(RV):
             ms.append(RVI.EvaluationMetrics(v))
         self._evaluation_metrics = ms
 
+    @property
+    def evaluation_periods(self):
+        """:EvaluationPeriod option. Instantiate with list of EvaluationPeriod commands."""
+        return "\n".join([str(p) for p in self._evaluation_periods])
+
+    @evaluation_periods.setter
+    def evaluation_periods(self, values):
+        if not isinstance(values, (list, set, tuple)):
+            values = [values]
+        self._evaluation_periods = values
+
     def _update_duration(self):
         if self.end_date is not None and self.start_date is not None:
             self._duration = (self.end_date - self.start_date).days
@@ -496,9 +510,8 @@ class RVP(RV):
     def __init__(self, config):
         super().__init__(config)
 
-        # Model specific params and derived params
+        # Model specific params
         self.params = None
-        self.derived_params = None
 
         self.soil_classes: Tuple[SoilClassesCommand.Record, ...] = ()
         self.soil_profiles: Tuple[SoilProfilesCommand.Record, ...] = ()
@@ -515,20 +528,12 @@ class RVP(RV):
                 assert isinstance(value, self._config.model_cls.Params)
                 self.params = value
             return True
-        elif key == "derived_params":
-            if is_sequence(value):
-                self.derived_params = self._config.model_cls.DerivedParams(*value)
-            else:
-                assert isinstance(value, self._config.model_cls.DerivedParams)
-                self.derived_params = value
-            return True
         else:
             return super().update(key, value)
 
     def to_rv(self):
         d = {
             "params": self.params,
-            "derived_params": self.derived_params,
             "soil_classes": SoilClassesCommand(self.soil_classes),
             "soil_profiles": SoilProfilesCommand(self.soil_profiles),
             "vegetation_classes": VegetationClassesCommand(self.vegetation_classes),
@@ -686,10 +691,7 @@ class RVT(RV):
         if key in self._var_specs:
             self._var_specs[key].update(value)
             return True
-        elif key == "nc_index":
-            self.nc_index = value
-            return True
-        return False
+        return super().update(key, value)
 
     def to_rv(self):
         """
@@ -800,6 +802,21 @@ class OST(RV):
     tmpl = """
     """
 
+    # Multiplier applied to metric before passing to minimization algorithm.
+    _evaluation_metrics_multiplier = dict(
+        NASH_SUTCLIFFE=-1,
+        LOG_NASH=-1,
+        RMSE=1,
+        PCT_BIAS="Not Supported",
+        ABSERR=1,
+        ABSMAX=1,
+        PDIFF=1,
+        TMVOL=1,
+        RCOEFF=1,
+        NSC=-1,
+        KLING_GUPTA=-1,
+    )
+
     def __init__(self, config):
         super().__init__(config)
 
@@ -846,6 +863,16 @@ class OST(RV):
         else:
             self._random_seed = None
 
+    @property
+    def evaluation_metric_multiplier(self):
+        """For Ostrich."""
+        m = self._config.rvi._evaluation_metrics[0]
+        if m.name == "PCT_BIAS":
+            raise ValueError(
+                "PCT_BIAS cannot be properly minimized. Select another evaluation metric."
+            )
+        return self._evaluation_metrics_multiplier[m.value]
+
     @property
     def identifier(self):
         return self._config.identifier
@@ -868,6 +895,8 @@ class OST(RV):
 
         d = {attr: getattr(self, attr) for attr in a + p}
 
+        d.update(self._extra_attributes)
+
         return dedent(self.tmpl).format(**d)
 
 
